PageAnimationInterface class abstract

Defines a page transition animation that PageAnimationTransition and PageAnimationTransitionPage can use to animate a route in and out.

Implement this to build a custom transition, or use one of the built-in implementations in package:page_animation_transition/animations/.

Implementers

Constructors

PageAnimationInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) → Widget
Wraps child with the transition widgets that define how the route arrives on and leaves the screen.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited