PageAnimationInterface class abstract
- Implementers
- BottomLeftToTopRightTransition
- BottomRightToTopLeftTransition
- BottomToTopFadedTransition
- BottomToTopTransition
- FadeAnimationTransition
- LeftToRightFadedTransition
- LeftToRightTransition
- RightToLeftFadedTransition
- RightToLeftTransition
- RotationAnimationTransition
- RotationFadedTransition
- ScaleAnimationTransition
- ScaleFadedTransition
- SizeAnimationTransition
- TopLeftToBottomRightTransition
- TopRightToBottomLeftTransition
- TopToBottomFadedTransition
- TopToBottomTransition
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
BuildContext context, Animation< double> animation, Animation<double> secondaryAnimation, Widget child) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited